@@ -548,11 +548,9 @@ class FeatureGenerator:
             - Cross-sectional ranks for each specified return period.
             - Cross-sectional z-scores for each return period.
         """
-        print(df_all)
-        print(df_all.columns)
+
 
         zscore_cols = [col for col in df_all.columns if "Z_Score" in col]
-        print(zscore_cols)
         for col in zscore_cols:
             rank_name = f"{col}_Cross_Sectional_Rank"
             df_all[rank_name] = df_all.groupby(datetime_column_name)[col].rank(method=rank_method,
@@ -560,7 +558,6 @@ class FeatureGenerator:
 
         # Step 3: Auto-detect pct_change columns and rank them cross-sectionally
         pct_cols = [col for col in df_all.columns if "pct_change" in col]
-        print(pct_cols)
         for col in pct_cols:
             rank_name = f"{col}_Cross_Sectional_Rank"
             df_all[rank_name] = df_all.groupby(datetime_column_name)[col].rank(method=rank_method,
